OptimizeRequestParams constructor
Constructs an OptimizeRequestParams object.
locations - The locations object is used to define all the locations to be used during optimization.
Read more about this attribute in the Locations Object section.
description - An optional description of the optimization request.
vehicles - The vehicles attribute describes the characteristics
and constraints of the vehicles that will be used for fulfilling the tasks.
shipments - The shipments object is used to collect the details of shipments
that need to be completed as part of the optimization process.
Each shipment should have a pickup and the corresponding delivery step.
For more information, You can check it in the API document(https://docs.nextbillion.ai/docs/optimization/api/route-optimization-flexible).
Implementation
OptimizeRequestParams({
required this.locations,
this.description,
required this.vehicles,
required this.shipments,
});